bayespy.nodes.GaussianMarkovChain.get_riemannian_gradient
=========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianMarkovChain.get_riemannian_gradient